@@ -243,7 +243,7 @@ class Tree:
         for node in to_contract:
             node.contract()
 
-    def deroot(self, label='OLDROOT'):
+    def drop_edge_length_at_root(self, label='OLDROOT'):
         '''If the tree has a root edge, drop the edge to be a child of the root node
 
         Args:
@@ -253,6 +253,21 @@ class Tree:
             self.root.add_child(Node(edge_length=self.root.edge_length,label=label))
             self.root.edge_length = None
 
+    def deroot(self):
+        '''If tree bifurcates at the root, contract an edge incident with the root to create a trifurcation at the root.
+
+        Args:
+            ``label`` (``str``): The desired label of the new child
+        '''
+        if self.root.num_children() == 1:
+            warn("Unable to unroot tree with unifurcation at the root!")
+        elif self.root.num_children() == 2:
+            [left, right] = self.root.child_nodes()
+            if left.is_leaf():
+                right.contract()
+            else:
+                left.contract()
+
     def diameter(self):
         '''Compute the diameter (maximum leaf pairwise distance) of this ``Tree``
 
@@ -403,7 +418,7 @@ class Tree:
         Args:
             ``show_plot`` (``bool``): ``True`` to show the plot, otherwise ``False``
 
-            ``export_filename`` (``str``): File to which the LTT figure will be exported (otherwise ``None`` to not save to file)
+            ``export_filename`` (``str``): File to which the tree figure will be exported (otherwise ``None`` to not save to file)
 
             ``show_labels`` (``bool``): ``True`` to show the leaf labels, otherwise ``False``
 
@@ -498,7 +513,7 @@ class Tree:
             if legend is None:
                 plt.savefig(export_filename)
             else:
-                plt.savefig(export_filename, bbox_extra_artists=(legend,))#, bbox_inches='tight')
+                plt.savefig(export_filename, bbox_extra_artists=(legend,))
         plt.close()
         for k in orig:
             rcParams[k] = orig[k]
